package com.coydone.servlet;

import com.coydone.domain.City;
import com.coydone.domain.Tour;
import com.coydone.service.CityService;
import com.coydone.service.TourService;
import com.coydone.service.impl.CityServiceImpl;
import com.coydone.service.impl.TourServiceImpl;
import com.coydone.utils.PageUtils;
import com.coydone.utils.WebUtils;

import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

@WebServlet(urlPatterns = "/tour")
public class TourServlet extends BaseServlet {
    private TourService tourService = new TourServiceImpl();
    public void list(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        Integer pageNo = WebUtils.parseInt(request.getParameter("pageNo"),1);
        Integer cityId = WebUtils.parseInt(request.getParameter("cityId"),0);
        String min = request.getParameter("min");
        String max = request.getParameter("max");

        PageUtils<Tour> pages = tourService.findAllByLimit(cityId, min, max, pageNo);
        CityService cityService = new CityServiceImpl();
        List<City> cities = cityService.findAll();

        request.setAttribute("pages", pages);
        request.getSession().setAttribute("cities",cities);
        request.setAttribute("cityId", cityId);
        request.setAttribute("min", min);
        request.setAttribute("max", max);

        request.getRequestDispatcher("/list.jsp").forward(request,response);
    }


    public void add(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        String introduce = request.getParameter("introduce");
        String price = request.getParameter("price");
        String cityId = request.getParameter("cityId");
        Date pubTime = null;
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        try {
            pubTime = sdf.parse(request.getParameter("pubTime"));
        } catch (ParseException e) {
            e.printStackTrace();
        }
        Tour tour = new Tour();
        tour.setIntroduce(introduce);
        tour.setPrice(Double.parseDouble(price));
        tour.setCityId(Integer.parseInt(cityId));
        tour.setPubTime(pubTime);

        Integer rows = tourService.add(tour);
        if (rows > 0) { //添加成功 返回到显示页面
            response.getWriter().print("<script>alert('添加成功');location.href='"+request.getContextPath()+"/index.jsp'</script>");
        } else { //添加失败 重新添加
            response.getWriter().print("<script>alert('添加失败');location.href='/add.jsp'</script>");
        }
    }

    //去修改页面
    public void toUpdate(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        Integer id = Integer.parseInt(request.getParameter("id"));
        Tour tour = tourService.findById(id);
        request.setAttribute("tour",tour);
        request.getRequestDispatcher("/update.jsp").forward(request,response);

    }

    //进行修改业务
    public void update(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        Integer id = Integer.parseInt(request.getParameter("id"));
        String introduce = request.getParameter("introduce");
        String price = request.getParameter("price");
        String cityId = request.getParameter("cityId");
        Date pubTime = null;
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        try {
            pubTime = sdf.parse(request.getParameter("pubTime"));
        } catch (ParseException e) {
            e.printStackTrace();
        }
        Tour tour = new Tour();

        tour.setId(id);
        tour.setIntroduce(introduce);
        tour.setPrice(Double.parseDouble(price));
        tour.setCityId(Integer.parseInt(cityId));
        tour.setPubTime(pubTime);

        Integer rows = tourService.updateById(tour);
        if (rows > 0) { //修改成功 返回到显示页面
            response.getWriter().print("<script>alert('修改成功');location.href='"+request.getContextPath()+"/index.jsp'</script>");
        } else { //修改失败 重新修改
            response.getWriter().print("<script>alert('修改失败');location.href='/update.jsp'</script>");
        }
    }

    //删除
    public void delete(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        Integer id = Integer.parseInt(request.getParameter("id"));
        Integer rows = tourService.deleteById(id);
        if (rows > 0) { //删除成功 返回到显示页面
            response.getWriter().print("<script>alert('删除成功');location.href='"+request.getContextPath()+"/index.jsp'</script>");
        } else { //删除失败
            response.getWriter().print("<script>alert('删除失败');location.href='/index.jsp'</script>");
        }
    }


    //景点详情
    public void view(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        Integer id = Integer.parseInt(request.getParameter("id"));
        Tour tour = tourService.findById(id);
        request.setAttribute("tour",tour);
        request.getRequestDispatcher("/view.jsp").forward(request,response);

    }
}
